@@ -1,16 +1,16 @@
-# @(#)Ident: Lock.pm 2013-08-04 16:50 pjf ;
+# @(#)Ident: Lock.pm 2013-11-22 18:32 pjf ;
 
 package Class::Usul::Lock;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.32.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.33.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
+use Moo;
 use Class::Usul::Constants;
 use Class::Usul::Functions  qw( emit );
+use Class::Usul::Options;
 use Class::Usul::Time;
 use Class::Usul::Types      qw( Int Str );
-use Moo;
-use MooX::Options;
 
 extends q(Class::Usul::Programs);
 
@@ -66,7 +66,7 @@ Class::Usul::Lock - Command line access to the L<IPC::SRLock> methods
 
 =head1 Version
 
-This documents version v0.32.$Rev: 1 $ of L<Class::Usul::Lock>
+This documents version v0.33.$Rev: 1 $ of L<Class::Usul::Lock>
 
 =head1 Synopsis
 
